<?php
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Elementor_Home1_Choose_Widget extends \Elementor\Widget_Base {

    public function get_name() {
        return 'home1_choose';
    }

    public function get_title() {
        return __( 'Home One Choose', 'gixus-core' );
    }

    public function get_icon() {
        return 'eicon-check-circle';
    }

    public function get_categories() {
        return [ 'gixus' ];
    }

    protected function _register_controls() {
        // Content Tab
        $this->start_controls_section(
            'content_section',
            [
                'label' => __( 'Content', 'gixus-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'experience_years_text',
            [
                'label' => __( 'Years of Experience', 'gixus-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => 'Years of Experience',
            ]
        );

        $this->add_control(
            'experience_years',
            [
                'label' => __( 'Years of Experience', 'gixus-core' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 26,
            ]
        );

        // Repeater for Progress Bars
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'progress_label',
            [
                'label' => __( 'Progress Label', 'gixus-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Business Development', 'gixus-core' ),
            ]
        );

        $repeater->add_control(
            'progress_percent',
            [
                'label' => __( 'Progress Percentage', 'gixus-core' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 65,
            ]
        );

        $this->add_control(
            'progress_items',
            [
                'label' => __( 'Progress Items', 'gixus-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'progress_label' => __( 'Business Development', 'gixus-core' ),
                        'progress_percent' => 65,
                    ],
                    [
                        'progress_label' => __( 'Investment Analysis', 'gixus-core' ),
                        'progress_percent' => 84,
                    ],
                ],
                'title_field' => '{{{ progress_label }}}',
            ]
        );

        $this->add_control(
            'main_title',
            [
                'label' => __( 'Main Title', 'gixus-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Building great future Together, Be with us', 'gixus-core' ),
            ]
        );

        // Repeater for Process Items
        $repeater_process = new \Elementor\Repeater();

        $repeater_process->add_control(
            'process_number',
            [
                'label' => __( 'Process Number', 'gixus-core' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 1,
            ]
        );

        $repeater_process->add_control(
            'process_title',
            [
                'label' => __( 'Process Title', 'gixus-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Information Collection', 'gixus-core' ),
            ]
        );

        $repeater_process->add_control(
            'process_description',
            [
                'label' => __( 'Process Description', 'gixus-core' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => __( 'Excuse Deal say over contain performance from comparison new melancholy themselves.', 'gixus-core' ),
            ]
        );

        $this->add_control(
            'process_items',
            [
                'label' => __( 'Process Items', 'gixus-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater_process->get_controls(),
                'default' => [
                    [
                        'process_number' => 1,
                        'process_title' => __( 'Information Collection', 'gixus-core' ),
                        'process_description' => __( 'Excuse Deal say over contain performance from comparison new melancholy themselves.', 'gixus-core' ),
                    ],
                    [
                        'process_number' => 2,
                        'process_title' => __( 'Projection Report Analysis', 'gixus-core' ),
                        'process_description' => __( 'Excuse Deal say over contain performance from comparison new melancholy themselves.', 'gixus-core' ),
                    ],
                    [
                        'process_number' => 3,
                        'process_title' => __( 'Consultation Solution', 'gixus-core' ),
                        'process_description' => __( 'Excuse Deal say over contain performance from comparison new melancholy themselves.', 'gixus-core' ),
                    ],
                ],
                'title_field' => '{{{ process_title }}}',
            ]
        );

        $this->end_controls_section();
    }

    protected function render() {
        $settings = $this->get_settings_for_display();
        ?>
        <div class="choose-us-style-one-area overflow-hidden default-padding-top bg-gray">
            <div class="container">
                <div class="heading-left">
                    <div class="row">
                        <div class="col-lg-5 offset-lg-1">
                            <div class="experience-style-one">
                                <h2><strong><?php echo esc_html( $settings['experience_years'] ); ?></strong> <?php echo esc_html( $settings['experience_years_text'] ); ?></h2>
                            </div>
                        </div>
                        <div class="col-lg-5 offset-lg-1">
                            <div class="circle-progress">
                                <?php foreach ( $settings['progress_items'] as $item ) : ?>
                                    <div class="progressbar">
                                        <div class="circle" data-percent="<?php echo esc_attr( $item['progress_percent'] ); ?>">
                                            <strong></strong>
                                        </div>
                                        <h4><?php echo esc_html( $item['progress_label'] ); ?></h4>
                                    </div>
                                <?php endforeach; ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="container container-stage">
                <div class="choose-us-one-thumb">
                    <div class="content">
                        <div class="left-info">
                            <h2 class="title split-text"><?php echo esc_html( $settings['main_title'] ); ?></h2>
                        </div>
                        <div class="process-style-one">
                            <?php foreach ( $settings['process_items'] as $index => $item ) : ?>
    						<div class="process-style-one-item wow fadeInRight" data-wow-delay="<?php echo esc_attr( ( $index * 200 ) . 'ms' ); ?>">
                                    <span><?php echo esc_html( sprintf('%02d', $item['process_number']) ); ?></span>
                                    <h4><?php echo esc_html( $item['process_title'] ); ?></h4>
                                    <p><?php echo esc_html( $item['process_description'] ); ?></p>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <?php
    }
}
